.. figure:: _static/logo/logo.png
   :width: 60%
   :align: center

Welcome to the documentation of **skpro** -- a domain-agnostic framework that allows for probabilistic modelling, namely the prediction of probability distributions, in supervised contexts.


Contents
========

.. toctree::
   :maxdepth: 2

   Introduction <introduction>
   Installation <installation>
   User guide <user_guide>
   Baseline strategies <baselines>
   Composite parametric prediction <parametric>
   Vendor integrations  <vendors>
   Meta-modelling <advanced>
   Workflow automation <workflow>
   Custom strategies <extending>
   API Reference <api/modules>
   Changelog <changes>
   Authors <authors>
   Contributing & Citation <contributing>
   License <license>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
